@@ -9,8 +9,11 @@ use Readonly;
 Readonly::Hash our %FIELD_504 => (
 	'cze' => qr{[rR]ejstřík},
 );
+Readonly::Hash our %FIELD_655 => (
+	'cze' => qr{komiksy|komiksové},
+);
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 1;
 
